function [add_noise_LT, add_noise_NT] = evalNoise(f, NT_node, LT_node, ...
start_node, stop_node, tot_len, Att_mtr, PSD_up, PSD_down, XTlevel);
%% ===========================================================================
%evalNoise - Calculates noise in LT and NT nodes from disturber in start to stop node 
%   PSD_up and PSD_down disturbers PSD masks
%
%   INPUT 
%   ------
%   f         : Frequency axis
%   NT_node   : NT node of disturbed modem        
%   LT_node   : LT node of disturbed modem    
%   start_node: LT node of disturber
%   stop_node : NT node of disturber
%   tot_len   : Length vector, tot_len(n)=distance to node n from the first node    
%   tot_Att   : Attenuation model in dB/km matrix
%   PSD_up    : Disturber PSD transmitted from NT end
%   PSD_down  : Disturber PSD transmitted from LT end
%   XTlevel   : Structure that contains NEXT,FEXT,thirdCXT values
%	       (XTlevel.NEXT XTlevel.FEXT XTlevel.thirdCXT must all
%	       have been assigned)
%
%   OUTPUT
%   -------
%   add_noise_LT(.NEXT .FEXT .thirdCXT): Noise to be added in LT end
%   add_noise_NT(.NEXT .FEXT .thirdCXT): Noise to be added in NT end
%
% Example(s):
%    See evalExperiment
%
% Algorithmic details:
%    Step 1:          Calculate noise in LT end         
%        Step 1.1:    NEXT from PSD_down
%        Step 1.2:    FEXT from PSD_up
%			Step 1.3:    3CXT from PSD_up
%        
%    Step 2:          Calculate noise in NT end         
%        Step 2.1:    NEXT from PSD_up
%        Step 2.2:    FEXT from PSD_down
%        Step 2.3:    3CXT from PSD_down
%        
%
% Reference:
%    FSAN xDSL simulation tool manual
%% ===========================================================================

%% ===========================================================================
% Copyright (C):                                        
%       1998-1999 by Telia Research AB, Lulea, Sweden;                
%       2000-2001 by Forschungszentrum Telekommunikation Wien, Austria;
%                                                         All rights reserved.
% Project       : FSAN duplex model
% Author(s)     : Tomas Nordstrom (Tomas.Nordstrom@FTW.at)
%               : Daniel Bengtsson (Daniel.J.Bengtsson@Telia.se)
%
% CVS:       $Id: evalNoise.m,v 1.10 2001/12/14 10:15:24 tono Exp $
%% ===========================================================================
% Change History:
%      1998-12-16 (DaB)	 Created      	 
%      1998-12-22 (ToNo) Added and updated comments
%      1999-01-08 (DaB)  Bug fixed in DS FEXT
%      1999-01-12 (DaB)  Fixed bug in US NEXT 
%      1999-02-04 (DaB)  Multiple cables allowed
%      1999-02-04 (DaB)  Added input parameter to control XTlevel
%                        (NEXT,FEXT, and thirdCXT)
%      1999-02-04 (DaB)  Added 3CXT noise
%      1999-02-09 (DaB)  Fixed NEXT FEXT thirdCXT add bug
%      1999-03-10 (DaB)  Rewritten to optimize speed
%      1999-03-30 (DaB)  Bug correction
%      1999-08-11 (DaB)  Updated for Bridgetap calc
%      2001-09-11 (ToNo) Added support for "4 order" NEXT term
%      2001-10-08 (ToNo) Made "4 order" NEXT flag global,
%                        and made some editorial changes.
%      2001-12-05 (ToNo) Fixed 4-order term to be |H|^2^2 instead of |H|^2^4
%% ===========================================================================

% --------------------------------
% Step 1: Generate noise in LT end  
% --------------------------------

%-----------------------------
% Step 1.1: NEXT from PSD_down              
%-----------------------------
tmp=zeros(size(f));
if NT_node<=start_node, 
    len_att=NaN;                                          % No overlap
elseif LT_node<stop_node,
    len_att=abs(tot_len(start_node)-tot_len(LT_node));
    if start_node>LT_node,
        att=Att_mtr{LT_node,start_node};
        if NT_node>stop_node,                              % Determine the common loop att
            attL=Att_mtr{start_node,NT_node};
        else
            attL=Att_mtr{start_node,stop_node};
        end
    else
        att=Att_mtr{start_node,LT_node};
        if NT_node>stop_node,                              % Determine the common loop att
            attL=Att_mtr{LT_node,NT_node};
        else
            attL=Att_mtr{LT_node,stop_node};
        end
    end; 
    if XTlevel.NEXTx4,
        dB_xtalk=XTlevel.NEXT+...
                 XTlevel.NEXTslant*log10(f./1e6)+ ...
                 10*log10(1-10.^(2*attL/10))+att;
    else         
        dB_xtalk=XTlevel.NEXT+15*log10(f./1e6)+att;
    end;
    xtalk=10.^(dB_xtalk/10);
    tmp=xtalk.*PSD_down;
else
    len_att=NaN;                                          % No overlap
end;  % if 
add_noise_LT.NEXT=tmp;

%---------------------------
% Step 1.2: FEXT from PSD_up
%---------------------------
tmp=zeros(size(f));
if (LT_node>=start_node)&(NT_node<=stop_node), 
    len_fext=tot_len(NT_node)-tot_len(LT_node);
    len_att=tot_len(stop_node)-tot_len(NT_node);
    if len_fext~=0,
        att=Att_mtr{LT_node,stop_node};
        dB_xtalk=XTlevel.FEXT+20.*log10(f/1e6)+10.*log10(len_fext)+att;
        xtalk=10.^(dB_xtalk/10);
        tmp=xtalk.*PSD_up;   
    end; % if
elseif (start_node<LT_node)&(stop_node<=LT_node),   
    len_fext=0;
    len_att=0;
elseif (start_node<LT_node)&(stop_node<NT_node),
    len_fext=tot_len(stop_node)-tot_len(LT_node);
    len_att=0;
    if len_fext~=0,
        att=Att_mtr{LT_node,stop_node};
        dB_xtalk=XTlevel.FEXT+20.*log10(f/1e6)+10.*log10(len_fext)+att;
        xtalk=10.^(dB_xtalk/10);
        tmp=xtalk.*PSD_up;      
    end; % if
elseif (LT_node<start_node)&(NT_node<=start_node),
    len_fext=0;
    len_att=0;      
elseif (LT_node<start_node)&(NT_node<stop_node),
    len_fext=tot_len(NT_node)-tot_len(start_node);
    len_att=tot_len(stop_node)-tot_len(NT_node)+tot_len(start_node)-tot_len(LT_node);
    if len_fext~=0,
        att=Att_mtr{LT_node,stop_node};
        dB_xtalk=XTlevel.FEXT+20.*log10(f/1e6)+10.*log10(len_fext)+att;
        xtalk=10.^(dB_xtalk/10);
        tmp=xtalk.*PSD_up;
    end; %if   
    
elseif (LT_node<=start_node)&(stop_node<=NT_node),
    len_fext=tot_len(stop_node)-tot_len(start_node);
    len_att=tot_len(start_node)-tot_len(LT_node);
    if len_fext~=0,
        att=Att_mtr{LT_node,stop_node};
        dB_xtalk=XTlevel.FEXT+20.*log10(f/1e6)+10.*log10(len_fext)+att;
        xtalk=10.^(dB_xtalk/10);
        tmp=xtalk.*PSD_up;
    end; %if   

end;  %if   
add_noise_LT.FEXT=tmp;
%----------------------------
% Step 1.3 3CXT from PSD_up
%----------------------------
tmp=zeros(size(f));
if (stop_node<=LT_node),
    len_att=tot_len(LT_node)-tot_len(stop_node);
    att=Att_mtr{stop_node,LT_node};
    dB_xtalk=XTlevel.thirdCXT+25.*log10(f/1e6)+att;
    xtalk=10.^(dB_xtalk/10);
    tmp=xtalk.*PSD_up;
end;
add_noise_LT.thirdCXT=tmp;

% ---------------------------------
% Step 2: Generate noise in NT end 
% --------------------------------

%---------------------------
% Step 2.1: NEXT from PSD_up
%---------------------------
tmp=zeros(size(f));
if (NT_node<=start_node)|(LT_node>=stop_node), % should this be there or not??
    len_att=NaN;
elseif NT_node>1,
    len_att=abs(tot_len(NT_node)-tot_len(stop_node)); 
    if NT_node>stop_node,
        att=Att_mtr{stop_node,NT_node};
        if LT_node>start_node,                              % Determine the common loop att
            attL=Att_mtr{LT_node,stop_node};
        else
            attL=Att_mtr{start_node,stop_node};
        end
    else
        att=Att_mtr{NT_node,stop_node};
        if LT_node>start_node,                              % Determine the common loop att
            attL=Att_mtr{LT_node,NT_node};
        else
            attL=Att_mtr{start_node,NT_node};
        end
    end;
    if XTlevel.NEXTx4,
        dB_xtalk=XTlevel.NEXT+...
                 XTlevel.NEXTslant*log10(f./1e6)+ ...
                 10*log10(1-10.^(2*attL/10))+att;
    else         
        dB_xtalk=XTlevel.NEXT+15*log10(f./1e6)+att;
    end
    xtalk=10.^(dB_xtalk/10);
    tmp=xtalk.*PSD_up;
else
    len_att=NaN;
end; %if
add_noise_NT.NEXT=tmp;

%-----------------------------
% Step 2.2: FEXT from PSD_down
%-----------------------------
tmp=zeros(size(f));
if (LT_node>=start_node)&(NT_node<=stop_node), 
    len_fext=tot_len(NT_node)-tot_len(LT_node);
    len_att=tot_len(LT_node)-tot_len(start_node);
    if len_fext~=0,
        att=Att_mtr{start_node,NT_node};
        dB_xtalk=XTlevel.FEXT+20.*log10(f/1e6)+10.*log10(len_fext)+att;
        xtalk=10.^(dB_xtalk/10);
        tmp=xtalk.*PSD_down;
    end; %if   
elseif (start_node<LT_node)&(stop_node<=LT_node)
    len_fext=0;
    len_att=0;
elseif (start_node<=LT_node)&(stop_node<NT_node),
    len_fext=tot_len(stop_node)-tot_len(LT_node);
    len_att=tot_len(NT_node)-tot_len(stop_node)+tot_len(LT_node)-tot_len(start_node);
    if len_fext~=0,
        att=Att_mtr{start_node,NT_node};
        dB_xtalk=XTlevel.FEXT+20.*log10(f/1e6)+10.*log10(len_fext)+att;
        xtalk=10.^(dB_xtalk/10);
        tmp=xtalk.*PSD_down;
    end; %if      
elseif (LT_node<start_node)&(NT_node<start_node),
    len_fext=0;
    len_att=0;
elseif (LT_node<start_node)&(NT_node<=stop_node),
    len_fext=tot_len(NT_node)-tot_len(start_node);
    len_att=0; %tot_len(stop_node)-tot_len(NT_node);
    if len_fext~=0,
        att=Att_mtr{start_node,NT_node};
        dB_xtalk=XTlevel.FEXT+20.*log10(f/1e6)+10.*log10(len_fext)+att;
        xtalk=10.^(dB_xtalk/10);
        tmp=xtalk.*PSD_down;
    end; %if 
end;  %if   
add_noise_NT.FEXT=tmp;

%-----------------------------
% Step 2.3: 3CXT from PSD_down
%-----------------------------
tmp=zeros(size(f));
if NT_node<=start_node,
    len_att=tot_len(start_node)-tot_len(NT_node);
    att=Att_mtr{NT_node,start_node};
    dB_xtalk=XTlevel.thirdCXT+25.*log10(f/1e6)+att;
    xtalk=10.^(dB_xtalk/10);
    tmp=xtalk.*PSD_down;
end;
add_noise_NT.thirdCXT=tmp;   

