function clist = etsi_cables(clist);
%% ===========================================================================
%etsi_cables(clist) - Sets up the cable models for ETSI
%
% Parameter:    clist          Structure describing the cables
% Returns:      clist          Structure describing the cables
%
% Example(s):
%   ex.clist = etsi_cables(ex.clist);            Add to existing clist
%   cableparam = getList(ex.clist,'BT_dwug');    Get BT dwug cable
%
%   ex.clist = etsi_cables([]);                  Create a new clist
%   cableparam = getList(ex.clist,'DTAG_04');    Get DTAG 4mm cable
%
% Reference:
%   ETSI VDSL TM6(97)02 (version 01-07-98)
%   ETSI SDSL test cables (CHECK Exact Reference)
%   ETSI STC TM6 Helsinki 2000 TD18
%   ETSI STC TM6 PD 980p10a5 "Laboratory Performance tests for xDSL
%   systems" (feb 5, 2001)
%   Draft ITU-T Recommendation G.996.1 "Test procedures for DSL tranceivers"
%   W. Henkel, et al. "Update of cable reference models", 
%   ETSI Contribution 985t04c0, Sopha Antipolis, France, Nov 24-27, 1998
%   ETSI STC TM6 RTS/TM-06025 rev1a 2001-09
%   ETSI TM6 021t32, Torino, Italy, 4th-8th Feb., 2002.
%   ETSI STC TM6 DTS/TM-06018 (Draft m00p10a5NC) 2001-03
%% ===========================================================================

%% ===========================================================================
% Copyright (C):                                        
%       1999 by Telia Research AB, Lulea, Sweden;                
%       2000-2002 by Forschungszentrum Telekommunikation Wien, Austria;
%                                                         All rights reserved.
% Project       : FSAN xDSL simulation tool
% Author(s)     : Tomas Nordstrom (Tomas.Nordstrom@FTW.at)
%               : Daniel Bengtsson (Daniel.J.Bengtsson@Telia.se)
%               : Gernot Schmid (Gernot.Schmid@arcs.ac.at)
%
% CVS:       $Id: etsi_cables.m,v 1.12 2002/06/05 15:26:48 tono Exp $
%% ===========================================================================
% Change History
%      1998-01-05 (Dab)  Moved to this project
%      1998-01-07 (ToNo) Added header and comments
%      1999-02-08 (DaB)  Fixed index bug in DTAG06 cable
%      1999-06-18 (ToNo) Removed one of the operators cables
%      2000-03-14 (ToNo) Moved cable defs. into xdsldefs and did the list thing
%      2000-03-16 (GS)   Added ETSI SDSL Test cables:
%                        PE04 PE05 PE06 PE08 PVC032 PVC04 PVC063
%      2000-06-07 (GS)   SDSL Test cable extensions beyond 500 kHz
%                        According to ETSI Helsinki 2000 TD18 
%      2000-07-18 (ToNo) Corrected the tan_fi values for KPN cables
%      2000-07-19 (ToNo) Changed so that r0s can be zero for BT models
%      2001-07-04 (ToNo) Added cable models used in ADSL simulations
%      2001-12-20 (ToNo) Added the modified DTAG model
%      2002-01-11 (ToNo) Added ETSI ADSL as param. models from ETSI 981t08a1
%      2002-01-12 (ToNo) Added ETSI ADSL as param. models from ITU 996.1
%      2002-01-27 (ToNo) Added ETSI ADSL as param. models MAR2 models
%      2002-02-01 (ToNo) Updated  the original ETSI ADSL parameters
%      2002-03-12 (ToNo) Updated the ETSI ADSL mar2 models suggested by ftw 
%      2002-03-18 (ToNo) Renamed the SDSL cables
%% ===========================================================================

c0 = 299792458; % speed of light (used in KPN model definitions)

%% ===========================================================================
% Finnish (Nokia) cables

% 0.4 mm
cable=[];
cable.name='NOK_40';
cable.model='BT';
cable.param.r0c=271.9983;
cable.param.r0s=0;
cable.param.ac=0.07960468;
cable.param.as=0;
cable.param.l0=710.7494e-6;
cable.param.loo=590.0163e-6;
cable.param.b=1.229532;
cable.param.fm=1.0300517e6;
cable.param.coo=38.6e-9;
cable.param.c0=0;
cable.param.ce=0;
cable.param.g0=1.100869e-9;
cable.param.ge=0.999424;
clist=insertList(clist,cable);

% 0.5 mm
cable=[];
cable.name='NOK_50';
cable.model='BT';
cable.param.r0c=173.99847;
cable.param.r0s=0;
cable.param.ac=0.0322326;
cable.param.as=0;
cable.param.l0=707.45088e-6;
cable.param.loo=581.5551e-6;
cable.param.b=1.095304;
cable.param.fm=693.804e3;
cable.param.coo=38.9e-9;
cable.param.c0=0;
cable.param.ce=0;
cable.param.g0=0.5007629e-9;
cable.param.ge=1.04681;
clist=insertList(clist,cable);

%% ===========================================================================
% British Telecom cables

% dw1 Single Pair 0.91 mm cadmium-copper conductor PVC insulated 
cable=[];
cable.name='BT_dw1';
cable.model='BT';
cable.param.r0c=65.32;
cable.param.r0s=0;
cable.param.ac=2.715283e-3;
cable.param.as=0;
cable.param.l0=0.884242e-3;
cable.param.loo=800.587e-6;
cable.param.b=1.30698;
cable.param.fm=263371;
cable.param.coo=28.0166e-9;
cable.param.c0=46.5668e-9;
cable.param.ce=0.117439;
cable.param.g0=855e-9;
cable.param.ge=0.746;
clist=insertList(clist,cable);

% dw3 Single Pair 0.72 mm copper coverd steel PVC insulated
cable=[];
cable.name='BT_dw3';
cable.model='BT';
cable.param.r0c=335.180;
cable.param.r0s=1281.3;
cable.param.ac=5.35389e-3;
cable.param.as=30286.34;
cable.param.l0=1.14166e-3;
cable.param.loo=708.221e-6;
cable.param.b=1.12676;
cable.param.fm=15211;
cable.param.coo=24.446503e-9;
cable.param.c0=34.431082e-9;
cable.param.ce=0.06589;
cable.param.g0=137.182e-9;
cable.param.ge=0.807645;
clist=insertList(clist,cable);

% dw5
cable=[];
cable.name='BT_dw5';
cable.model='BT';
cable.param.r0c=335.321;
cable.param.r0s=1116.45012;
cable.param.ac=10.996373e-3;
cable.param.as=13175.463;
cable.param.l0=1.13771e-3;
cable.param.loo=792.766e-6;
cable.param.b=1.52968;
cable.param.fm=20842.6;
cable.param.coo=29.297887e-9;
cable.param.c0=31.60789e-9;
cable.param.ce=0.1115489;
cable.param.g0=32.574128e-9;
cable.param.ge=0.919;
clist=insertList(clist,cable);

% dw6 Single Pair 0.81 mm copper covered steel conductor PVC insulated 
cable=[];
cable.name='BT_dw6';
cable.model='BT';
cable.param.r0c=270.70256;
cable.param.r0s=774.23224;
cable.param.ac=2.48956e-3;
cable.param.as=3349.76;
cable.param.l0=1.10646e-3;
cable.param.loo=760.267e-6;
cable.param.b=1.35790;
cable.param.fm=15668;
cable.param.coo=27.8941e-9;
cable.param.c0=39.4114e-9;
cable.param.ce=0.106593;
cable.param.g0=360e-9;
cable.param.ge=0.777;
clist=insertList(clist,cable);

% dw8 Single Pair flat twin 1.14 mm cadmium-copper conductor PVC insulated 
cable=[];
cable.name='BT_dw8';
cable.model='BT';
cable.param.r0c=41.16;
cable.param.r0s=0;
cable.param.ac=1.2179771e-3;
cable.param.as=0;
cable.param.l0=1e-3;
cable.param.loo=910.505e-6;
cable.param.b=1.1952665;
cable.param.fm=174877;
cable.param.coo=22.681213e-9;
cable.param.c0=31.778569e-9;
cable.param.ce=0.11086674;
cable.param.g0=53e-9;
cable.param.ge=0.88;
clist=insertList(clist,cable);

% dw10 2 Pair 0.5 mm copper conductor PVC ins. PVC ins. steel Polyeth. sheath 
cable=[];
cable.name='BT_dw10';
cable.model='BT';
cable.param.r0c=180.93;
cable.param.r0s=0;
cable.param.ac=0.0497223;
cable.param.as=0;
cable.param.l0=728.8683e-6;
cable.param.loo=543.4352e-6;
cable.param.b=0.75577086;
cable.param.fm=718888;
cable.param.coo=50.928328e-9;
cable.param.c0=63.824345e-9;
cable.param.ce=0.11584622;
cable.param.g0=89.041038e-9;
cable.param.ge=0.85606301;
clist=insertList(clist,cable);

% dw12 Single Pair 0.9 mm copper conductor Pol.ins. PVC cov. steel Pol.sheath  
cable=[];
cable.name='BT_dw12';
cable.model='BT';
cable.param.r0c=55.460555;
cable.param.r0s=0;
cable.param.ac=4.9924627e-3;
cable.param.as=0;
cable.param.l0=0.62104396e-3;
cable.param.loo=461.954e-6;
cable.param.b=0.93970931;
cable.param.fm=193049;
cable.param.coo=51.128076e-9;
cable.param.c0=5.802245e-9;
cable.param.ce=0.10064577;
cable.param.g0=20e-9;
cable.param.ge=0.88;
clist=insertList(clist,cable);

% dwug mult pair 0.5 mm copper Poly. ins. Underground dist.
cable=[];
cable.name='BT_dwug';
cable.model='BT';
cable.param.r0c=179;
cable.param.r0s=0;
cable.param.ac=35.89e-3;
cable.param.as=0;
cable.param.l0=0.695e-3;
cable.param.loo=585e-6;
cable.param.b=1.2;
cable.param.fm=1e6;
cable.param.coo=55e-9;
cable.param.c0=1e-9;
cable.param.ce=0.1;
cable.param.g0=0.5e-9;
cable.param.ge=1.033;
clist=insertList(clist,cable);

%% ===========================================================================
%  US cables

% TP1 0.4 mm 26-AWG 
cable=[];
cable.name='ANSI_TP1';
cable.model='BT';
cable.param.r0c=286.17578;
cable.param.r0s=0;
cable.param.ac=0.14769620;
cable.param.as=0.0;
cable.param.l0=675.36888e-6;
cable.param.loo=488.95186e-6;
cable.param.b=0.92930728;
cable.param.fm=806.33863e3;
cable.param.coo=49e-9;
cable.param.c0=0;
cable.param.ce=0;
cable.param.g0=43e-9;
cable.param.ge=0.7;
clist=insertList(clist,cable);

% TP2 0.5 mm 24-AWG 
cable=[];
cable.name='ANSI_TP2';
cable.model='BT';
cable.param.r0c=174.55888;
cable.param.r0s=0;
cable.param.ac=0.053073481;
cable.param.as=0.0;
cable.param.l0=617.29539e-6;
cable.param.loo=478.97099e-6;
cable.param.b=1.1529766;
cable.param.fm=553.760e3;
cable.param.coo=50e-9;
cable.param.c0=0;
cable.param.ce=0;
cable.param.g0=234.87476e-15;
cable.param.ge=1.38;
clist=insertList(clist,cable);

% TP3 DW10 0.5mm copper PVC ins. Poly. sheath
cable=[];
cable.name='ANSI_TP3';
cable.model='BT';
cable.param.r0c=180.93;
cable.param.r0s=0;
cable.param.ac=0.0497223;
cable.param.as=0.0;
cable.param.l0=728.87e-6;
cable.param.loo=543.43e-6;
cable.param.b=0.75577086;
cable.param.fm=718.888e3;
cable.param.coo=51e-9;
cable.param.c0=63.8e-9;
cable.param.ce=0.11584622;
cable.param.g0=89e-9;
cable.param.ge=0.856;
clist=insertList(clist,cable);


%% ===========================================================================
% FP 1.14mm flat twin DW8
cable=[];
cable.name='ANSI_FP';
cable.model='BT';
cable.param.r0c=41.16;
cable.param.r0s=0;
cable.param.ac=0.001218;
cable.param.as=0.0;
cable.param.l0=1000e-6;
cable.param.loo=911e-6;
cable.param.b=1.195;
cable.param.fm=174877;
cable.param.coo=22.68e-9;
cable.param.c0=31.78e-9;
cable.param.ce=0.1109;
cable.param.g0=53e-9;
cable.param.ge=0.88;
clist=insertList(clist,cable);


%% ===========================================================================
% Original Deutsche Telekom AG cables

% 0.35 mm
cable=[];
cable.name='DTAG_35o';
cable.model='DTAGorg';
cable.param.Ka1=[9.4 2.4 15.9];
cable.param.Ka2=[13.2 19.9 11.2];
cable.param.Ka3=[0.97 0.54 0.69];
cable.param.Kb1=34.2;
cable.param.Kb2=2.62;
cable.param.Kz1=132;
cable.param.Kz2=5;
cable.param.Kz3=0.73;
cable.param.Kx1=0.05;
cable.param.Kx2=0.024;
cable.param.Kx3=0.87;
clist=insertList(clist,cable);

% 0.40 mm
cable=[];
cable.name='DTAG_40o';
cable.model='DTAGorg';
cable.param.Ka1=[6.9 0.3 10.4];
cable.param.Ka2=[13.4 18.9 11.5];
cable.param.Ka3=[0.99 0.5 0.64];
cable.param.Kb1=32.9;
cable.param.Kb2=2.26;
cable.param.Kz1=127;
cable.param.Kz2=8.8;
cable.param.Kz3=0.51;
cable.param.Kx1=0.045;
cable.param.Kx2=0.016;
cable.param.Kx3=0.81;
clist=insertList(clist,cable);

% 0.50 mm
cable=[];
cable.name='DTAG_50o';
cable.model='DTAGorg';
cable.param.Ka1=[4.2 0.7 10.3];
cable.param.Ka2=[11.9 14.1 7.7];
cable.param.Ka3=[0.92 0.52 0.68];
cable.param.Kb1=30.6;
cable.param.Kb2=1.62;
cable.param.Kz1=141;
cable.param.Kz2=3.4;
cable.param.Kz3=0.69;
cable.param.Kx1=0.038;
cable.param.Kx2=0.0082;
cable.param.Kx3=0.73;
clist=insertList(clist,cable);

% 0.60 mm
cable=[];
cable.name='DTAG_60o';
cable.model='DTAGorg';
cable.param.Ka1=[2.4 1.1 8.7];
cable.param.Ka2=[11.2 11.6 6.6];
cable.param.Ka3=[0.75 0.54 0.69];
cable.param.Kb1=30.4;
cable.param.Kb2=1.62;
cable.param.Kz1=135;
cable.param.Kz2=3.4;
cable.param.Kz3=0.63;
cable.param.Kx1=0.036;
cable.param.Kx2=0.0038;
cable.param.Kx3=0.64;
clist=insertList(clist,cable);

%% ===========================================================================
% Updated Deutsche Telekom AG cables
%   W. Henkel, et al. "Update of cable reference models", 
%   ETSI Contribution 985t04c0, Sopha Antipolis, France, Nov 24-27, 1998

% 0.35 mm
cable=[];
cable.name='DTAG_35';
cable.model='DTAG';
cable.param.Ka1=[9.4 2.4 15.9];
cable.param.Ka2=[13.2 19.9 11.2];
cable.param.Ka3=[0.97 0.54 0.69];
cable.param.Kb1=[35.06, 33.96, 34.13];
cable.param.Kb2=[1.725, 2.700, 2.458];
cable.param.Kb3=[0.545, 0.585, 0.560];
cable.param.Kz1=132;
cable.param.Kz2=5;
cable.param.Kz3=0.73;
cable.param.Kx1=0.05;
cable.param.Kx2=0.024;
cable.param.Kx3=0.87;
clist=insertList(clist,cable);

% 0.40 mm
cable=[];
cable.name='DTAG_40';
cable.model='DTAG';
cable.param.Ka1=[6.9 0.3 10.4];
cable.param.Ka2=[13.4 18.9 11.5];
cable.param.Ka3=[0.99 0.5 0.64];
cable.param.Kb1=[33.47, 32.82, 32.87];
cable.param.Kb2=[1.782, 2.229, 2.113];
cable.param.Kb3=[0.601, 0.543, 0.543];
cable.param.Kz1=127;
cable.param.Kz2=8.8;
cable.param.Kz3=0.51;
cable.param.Kx1=0.045;
cable.param.Kx2=0.016;
cable.param.Kx3=0.81;
clist=insertList(clist,cable);

% 0.50 mm
cable=[];
cable.name='DTAG_50';
cable.model='DTAG';
cable.param.Ka1=[4.2 0.7 10.3];
cable.param.Ka2=[11.9 14.1 7.7];
cable.param.Ka3=[0.92 0.52 0.68];
cable.param.Kb1=[29.45, 30.53, 30.57];
cable.param.Kb2=[2.899, 1.728, 1.676];
cable.param.Kb3=[0.739, 0.529, 0.516];
cable.param.Kz1=141;
cable.param.Kz2=3.4;
cable.param.Kz3=0.69;
cable.param.Kx1=0.038;
cable.param.Kx2=0.0082;
cable.param.Kx3=0.73;
clist=insertList(clist,cable);

% 0.60 mm
cable=[];
cable.name='DTAG_60';
cable.model='DTAG';
cable.param.Ka1=[2.4 1.1 8.7];
cable.param.Ka2=[11.2 11.6 6.6];
cable.param.Ka3=[0.75 0.54 0.69];
cable.param.Kb1=[28.94, 30.43, 30.43];
cable.param.Kb2=[2.950, 1.459, 1.449];
cable.param.Kb3=[0.736, 0.508, 0.509];
cable.param.Kz1=135;
cable.param.Kz2=3.4;
cable.param.Kz3=0.63;
cable.param.Kx1=0.036;
cable.param.Kx2=0.0038;
cable.param.Kx3=0.64;
clist=insertList(clist,cable);

%% ===========================================================================
% Royal Dutch Telecom (KPN) cables

% KPN_L1
cable=[];
cable.name='KPN_L1';
cable.model='KPN';
cable.param.Z0oo=136.651;
cable.param.c=0.79766*c0;
cable.param.Rss00=0.168145;
cable.param.tan_fi=0.13115/(2*pi);
cable.param.Kf=0.72;
cable.param.K1=1.2;
cable.param.Kn=1;
cable.param.Kc=1.08258;
cable.param.N=0.7;
cable.param.fc0=4521710;
cable.param.M=1;
clist=insertList(clist,cable);

% KPN_L2
cable=[];
cable.name='KPN_L2';
cable.model='KPN';
cable.param.Z0oo=136.047;
cable.param.c=0.798958*c0;
cable.param.Rss00=0.168145;
cable.param.tan_fi=0.16998/(2*pi);
cable.param.Kf=0.7;
cable.param.K1=1.1;
cable.param.Kn=1;
cable.param.Kc=1.08201;
cable.param.N=1;
cable.param.fc0=1862950;
cable.param.M=1;
clist=insertList(clist,cable);

% KPN_L3
cable=[];
cable.name='KPN_L3';
cable.model='KPN';
cable.param.Z0oo=137.527;
cable.param.c=0.850608*c0;
cable.param.Rss00=0.065682;
cable.param.tan_fi=0.114526/(2*pi);
cable.param.Kf=1;
cable.param.K1=1;
cable.param.Kn=1;
cable.param.Kc=1.06967;
cable.param.N=1;
cable.param.fc0=559844;
cable.param.M=1;
clist=insertList(clist,cable);

% KPN_L4
cable=[];
cable.name='KPN_L4';
cable.model='KPN';
cable.param.Z0oo=137.005;
cable.param.c=0.787661*c0;
cable.param.Rss00=0.168145;
cable.param.tan_fi=0.153522/(2*pi);
cable.param.Kf=0.9;
cable.param.K1=1;
cable.param.Kn=1;
cable.param.Kc=1.07478;
cable.param.N=1;
cable.param.fc0=557458;
cable.param.M=1;
clist=insertList(clist,cable);

% KPN_H1
cable=[];
cable.name='KPN_H1';
cable.model='KPN';
cable.param.Z0oo=135.458;
cable.param.c=0.640381*c0;
cable.param.Rss00=0.177728;
cable.param.tan_fi=0.018425/(2*pi);
cable.param.Kf=0.85;
cable.param.K1=1;
cable.param.Kn=1;
cable.param.Kc=1.11367;
cable.param.N=1.5;
cable.param.fc0=5020;
cable.param.M=1;
clist=insertList(clist,cable);

% KPN_KK
cable=[];
cable.name='KPN_KK';
cable.model='KPN';
cable.param.Z0oo=142.451;
cable.param.c=0.712318*c0;
cable.param.Rss00=0.177728;
cable.param.tan_fi=0.071111/(2*pi);
cable.param.Kf=0.8;
cable.param.K1=1.1;
cable.param.Kn=1;
cable.param.Kc=1.09373;
cable.param.N=0.5;
cable.param.fc0=8088;
cable.param.M=1;
clist=insertList(clist,cable);

% KPN_R2
cable=[];
cable.name='KPN_R2';
cable.model='KPN';
cable.param.Z0oo=97.4969;
cable.param.c=0.639405*c0;
cable.param.Rss00=0.177728;
cable.param.tan_fi=0.0189898/(2*pi);
cable.param.Kf=0.5;
cable.param.K1=1.14;
cable.param.Kn=1;
cable.param.Kc=1;
cable.param.N=1;
cable.param.fc0=100000;
cable.param.M=1;
clist=insertList(clist,cable);

%% ===========================================================================
%  Define some commonly used aliases

cable=getList(clist,'BT_dwug');
cable.name='ETSI';
clist=insertList(clist,cable);

cable=getList(clist,'ANSI_TP1');
cable.name='ANSI';
clist=insertList(clist,cable);

cable=getList(clist,'BT_dwug');
cable.name='TP100';
clist=insertList(clist,cable);

cable=getList(clist,'BT_dw8');
cable.name='TP180x';
clist=insertList(clist,cable);

cable=getList(clist,'KPN_L1');
cable.name='TP150';
clist=insertList(clist,cable);

cable=getList(clist,'KPN_R2');
cable.name='TP100x';
clist=insertList(clist,cable);

%%============================================================================
% ETSI - SDSL/HDSL Testcables only defined up to 2 MHz
% From  ETSI STC TM6 DTS/TM-06018 (Draft m00p10a5NC) 2001-03

cable=[];
cable.name='ETSI-SDSL-PE04';
cable.model='RLC';
cable.param.ftmpl=[0 10e3 20e3 40e3 100e3 150e3 200e3 400e3 500e3 700e3 1e6 2e6];  % in Hz
cable.param.Rtmpl=1e-3.*[268 268 269 271 282 295 312 390 425 493 582 816];       % in Ohm/m
cable.param.Ltmpl=1e-9.*[680 678 675 669 650 642 635 619 608 593 582 571];       % in H/m
cable.param.Ctmpl=1e-12.*[45.5 45.5 45.5 45.5 45.5 45.5 45.5 45.5 45.5 45.5 45.5 45.5];%in F/m
clist=insertList(clist,cable);

cable=[];
cable.name='ETSI-SDSL-PE05';
cable.model='RLC';
cable.param.ftmpl=[0 10e3 20e3 40e3 100e3 150e3 200e3 400e3 500e3 700e3 1e6 2e6];  % in Hz 
cable.param.Rtmpl=1e-3.*[172 172 173 175 190 207 227 302 334 392 466 655];       % in Ohm/m
cable.param.Ltmpl= 1e-9.*[680 678 675 667 646 637 629 603 592 577 572 565];      % in H/m
cable.param.Ctmpl= 1e-12.*[25 25 25 25 25 25 25 25 25 25 25 25];              % in F/m
clist=insertList(clist,cable);

cable=[];
cable.name='ETSI-SDSL-PE06';
cable.model='RLC';
cable.param.ftmpl=[0 10e3 20e3 40e3 100e3 150e3 200e3 400e3 500e3 700e3 1e6 2e6];  % in Hz 
cable.param.Rtmpl=1e-3.*[119 120 121 125 146 167 189 260 288 340 405 571];       % in Ohm/m
cable.param.Ltmpl=1e-9.*[700 695 693 680 655 641 633 601 590 576 570 560];       % in H/m  
cable.param.Ctmpl=1e-12.*[56 56 56 56 56 56 56 56 56 56 56 56];               % in F/m  
clist=insertList(clist,cable);
    
cable=[];
cable.name='ETSI-SDSL-PE08';
cable.model='RLC';
cable.param.ftmpl=[0 10e3 20e3 40e3 100e3 150e3 200e3 400e3 500e3 700e3 1e6 2e6];  % in Hz  
cable.param.Rtmpl=1e-3.*[67 70 72.5 75.0 91.7 105 117 159 177.5 209 250 353];    % in Ohm/m
cable.param.Ltmpl=1e-9.*[700 700 687 655 628 609 595 568 560 553 547 540];       % in H/m  
cable.param.Ctmpl=1e-12.*[37.8 37.8 37.8 37.8 37.8 37.8 37.8 37.8 37.8 37.8 37.8 37.8];%in F/m
clist=insertList(clist,cable);

cable=[];
cable.name='ETSI-SDSL-PVC032';
cable.model='RLC';
cable.param.ftmpl=[0 10e3 20e3 40e3 100e3 150e3 200e3 400e3 500e3 700e3 1e6 2e6]; % in Hz
cable.param.Rtmpl= 1e-3.*[419 419 419 419 427 453 493 679 750 877 1041 1463];     % in Ohm/m 
cable.param.Ltmpl= 1e-9.*[650 650 650 650 647 635 621 577 560 546 545 540];     % in H/m 
cable.param.Ctmpl= 1e-12.*[120 120 120 120 120 120 120 120 120 120 120 120];    % in F/m 
clist=insertList(clist,cable);
 
cable=[];
cable.name='ETSI-SDSL-PVC04';
cable.model='RLC';
cable.param.ftmpl=[0 10e3 20e3 40e3 100e3 150e3 200e3 400e3 500e3 700e3 1e6 2e6];  % in Hz  
cable.param.Rtmpl=1e-3.*[268 268 268 268 281 295 311 391 426 494 584 817];       % in Ohm/m
cable.param.Ltmpl=1e-9.*[650 650 650 650 635 627 619 592 579 566 559 550];       % in H/m  
cable.param.Ctmpl= 1e-12.*[120 120 120 120 120 120 120 120 120 120 120 120];     % in F/m 
clist=insertList(clist,cable);

cable=[];
cable.name='ETSI-SDSL-PVC063';
cable.model='RLC';
cable.param.ftmpl=[0 10e3 20e3 40e3 100e3 150e3 200e3 400e3 500e3 700e3 1e6 2e6];  % in Hz 
cable.param.Rtmpl=1e-3.*[108 108 108 111 141 173 207 319 361 427 510 720];       % in Ohm/m
cable.param.Ltmpl=1e-9.*[635 635 635 630 604 584 560 492 469 450 442 434];       % in H/m  
cable.param.Ctmpl= 1e-12.*[120 120 120 120 120 120 120 120 120 120 120 120];     % in F/m 
clist=insertList(clist,cable);

%%============================================================================
% ETSI - ADSL 
% From ETSI STC TM6 RTS/TM-06025 rev1a 2001-09
%
% NOTE: Testcables only defined up to 1.1 MHz, thus we need to
% extrapolate for the tone at 1104 kHz!
% Use one of the PE0Xm or PE0Xi models below instead!


cable=[];
cable.name='ETSI-ADSL-PE032';
cable.model='RLC';
params = [0.00 409.000 607.639 40.00
2.50 409.009 607.639 40.00
10.00 409.140 607.639 40.00
20.00 409.557 607.639 40.00
30.00 410.251 607.639 40.00
40.00 411.216 607.639 40.00
50.00 412.447 607.639 40.00
100.00 422.302 607.631 40.00
150.00 437.337 607.570 40.00
200.00 456.086 607.327 40.00
250.00 477.229 606.639 40.00
300.00 499.757 605.074 40.00
350.00 522.967 602.046 40.00
400.00 546.395 596.934 40.00
450.00 569.748 589.337 40.00
500.00 592.843 579.376 40.00
550.00 615.576 567.822 40.00
600.00 637.885 555.867 40.00
650.00 659.743 544.657 40.00
700.00 681.138 534.942 40.00
750.00 702.072 526.991 40.00
800.00 722.556 520.732 40.00
850.00 742.601 515.919 40.00
900.00 762.224 512.264 40.00
950.00 781.442 509.503 40.00
1000.00 800.272 507.415 40.00
1050.00 818.731 505.831 40.00
1100.00 836.837 504.623 40.00
];
cable.param.ftmpl=1e3.*params(:,1);
cable.param.Rtmpl=1e-3.*params(:,2);
cable.param.Ltmpl=1e-9.*params(:,3);
cable.param.Ctmpl=1e-12.*params(:,4);
clist=insertList(clist,cable);

cable=[];
cable.name='ETSI-ADSL-PE04';
cable.model='RLC';
params = [0.00 280.000 587.132 50.00
2.50 280.007 587.075 50.00
10.00 280.110 586.738 50.00
20.00 280.440 586.099 50.00
30.00 280.988 585.322 50.00
40.00 281.748 584.443 50.00
50.00 282.718 583.483 50.00
100.00 290.433 577.878 50.00
150.00 302.070 571.525 50.00
200.00 316.393 564.889 50.00
250.00 332.348 558.233 50.00
300.00 349.167 551.714 50.00
350.00 366.345 545.431 50.00
400.00 383.562 539.437 50.00
450.00 400.626 533.759 50.00
500.00 417.427 528.409 50.00
550.00 433.904 523.385 50.00
600.00 450.027 518.677 50.00
650.00 465.785 514.272 50.00
700.00 481.180 510.153 50.00
750.00 496.218 506.304 50.00
800.00 510.912 502.707 50.00
850.00 525.274 499.343 50.00
900.00 539.320 496.197 50.00
950.00 553.064 493.252 50.00
1000.00 566.521 490.494 50.00
1050.00 579.705 487.908 50.00
1100.00 592.628 485.481 50.00
];
cable.param.ftmpl=1e3.*params(:,1);
cable.param.Rtmpl=1e-3.*params(:,2);
cable.param.Ltmpl=1e-9.*params(:,3);
cable.param.Ctmpl=1e-12.*params(:,4);
clist=insertList(clist,cable);

cable=[];
cable.name='ETSI-ADSL-PE05';
cable.model='RLC';
params = [0.00 179.000 673.574 50.00
2.50 179.015 673.466 50.00
10.00 179.244 672.923 50.00
20.00 179.970 671.980 50.00
30.00 181.161 670.896 50.00
40.00 182.790 669.716 50.00
50.00 184.822 668.468 50.00
100.00 199.608 661.677 50.00
150.00 218.721 654.622 50.00
200.00 239.132 647.735 50.00
250.00 259.461 641.208 50.00
300.00 279.173 635.119 50.00
350.00 298.103 629.489 50.00
400.00 316.230 624.309 50.00
450.00 333.591 619.557 50.00
500.00 350.243 615.202 50.00
550.00 366.246 611.211 50.00
600.00 381.657 607.552 50.00
650.00 396.528 604.192 50.00
700.00 410.907 601.104 50.00
750.00 424.835 598.261 50.00
800.00 438.348 595.639 50.00
850.00 451.480 593.217 50.00
900.00 464.258 590.975 50.00
950.00 476.710 588.896 50.00
1000.00 488.857 586.966 50.00
1050.00 500.720 585.169 50.00
1100.00 512.317 583.495 50.00
];
cable.param.ftmpl=1e3.*params(:,1);
cable.param.Rtmpl=1e-3.*params(:,2);
cable.param.Ltmpl=1e-9.*params(:,3);
cable.param.Ctmpl=1e-12.*params(:,4);
clist=insertList(clist,cable);

cable=[];
cable.name='ETSI-ADSL-PE063';
cable.model='RLC';
params = [0.00 113.000 699.258 45.00
2.50 113.028 697.943 45.00
10.00 113.442 693.361 45.00
20.00 114.737 687.008 45.00
30.00 116.803 680.714 45.00
40.00 119.523 674.593 45.00
50.00 122.768 668.690 45.00
100.00 143.115 642.718 45.00
150.00 164.938 622.050 45.00
200.00 185.689 605.496 45.00
250.00 204.996 592.048 45.00
300.00 222.961 580.960 45.00
350.00 239.764 571.691 45.00
400.00 255.575 563.845 45.00
450.00 270.533 557.129 45.00
500.00 284.753 551.323 45.00
550.00 298.330 546.260 45.00
600.00 311.339 541.809 45.00
650.00 323.844 537.868 45.00
700.00 335.897 534.358 45.00
750.00 347.542 531.212 45.00
800.00 358.819 528.378 45.00
850.00 369.758 525.813 45.00
900.00 380.388 523.480 45.00
950.00 390.734 521.352 45.00
1000.00 400.816 519.402 45.00
1050.00 410.654 517.609 45.00
1100.00 420.264 515.956 45.00
];
cable.param.ftmpl=1e3.*params(:,1);
cable.param.Rtmpl=1e-3.*params(:,2);
cable.param.Ltmpl=1e-9.*params(:,3);
cable.param.Ctmpl=1e-12.*params(:,4);
clist=insertList(clist,cable);

cable=[];
cable.name='ETSI-ADSL-PE09';
cable.model='RLC';
params = [0.00 55.000 750.796 40.00
2.50 55.088 745.504 40.00
10.00 56.361 731.961 40.00
20.00 59.941 716.775 40.00
30.00 64.777 703.875 40.00
40.00 70.127 692.707 40.00
50.00 75.586 682.914 40.00
100.00 100.769 647.496 40.00
150.00 121.866 625.140 40.00
200.00 140.075 609.652 40.00
250.00 156.273 598.256 40.00
300.00 170.987 589.504 40.00
350.00 184.556 582.563 40.00
400.00 197.208 576.919 40.00
450.00 209.104 572.237 40.00
500.00 220.365 568.287 40.00
550.00 231.081 564.910 40.00
600.00 241.326 561.988 40.00
650.00 251.155 559.435 40.00
700.00 260.615 557.183 40.00
750.00 269.745 555.183 40.00
800.00 278.577 553.394 40.00
850.00 287.138 551.784 40.00
900.00 295.452 550.327 40.00
950.00 303.538 549.002 40.00
1000.00 311.416 547.793 40.00
1050.00 319.099 546.683 40.00
1100.00 326.602 545.663 40.00
];
cable.param.ftmpl=1e3.*params(:,1);
cable.param.Rtmpl=1e-3.*params(:,2);
cable.param.Ltmpl=1e-9.*params(:,3);
cable.param.Ctmpl=1e-12.*params(:,4);
clist=insertList(clist,cable);

%% ===========================================================================
% ETSI ADSL as models from ETSI 981t08a1

cable=[];
cable.name='ETSI-ADSL-PE032m';
cable.model='BT';

Ro     = 409;
Linf   = 500.00e-6;
Fr     = 270.59e3;
LoLinf = 107.64e-6;
Fm     = 608.77e3;
Nb     = 5.2464;
Cp     = 40e-9;

cable.param.r0c = Ro;    
cable.param.r0s = 0;
cable.param.ac  = (Ro^2/Fr)^2;
cable.param.as  = 0;
cable.param.l0  = LoLinf + Linf;
cable.param.loo = Linf; 
cable.param.b   = Nb;     
cable.param.fm  = Fm;    
cable.param.coo = Cp;
cable.param.c0  = 0;
cable.param.ce  = 0;
cable.param.g0  = 0;
cable.param.ge  = 1;
clist=insertList(clist,cable);


cable=[];
cable.name='ETSI-ADSL-PE04m';
cable.model='BT';

Ro     = 280;
Linf   = 427.12e-6;
Fr     = 251.91e3;
LoLinf = 160.01e-6;
Fm     = 739.05e3;
Nb     = 1.3952;
Cp     = 50e-9;

cable.param.r0c = Ro;    
cable.param.r0s = 0;
cable.param.ac  = (Ro^2/Fr)^2;
cable.param.as  = 0;
cable.param.l0  = LoLinf + Linf;
cable.param.loo = Linf; 
cable.param.b   = Nb;     
cable.param.fm  = Fm;    
cable.param.coo = Cp;
cable.param.c0  = 0;
cable.param.ce  = 0;
cable.param.g0  = 0;
cable.param.ge  = 1;
clist=insertList(clist,cable);

cable=[];
cable.name='ETSI-ADSL-PE05m';
cable.model='BT';

Ro     = 179;
Linf   = 544.25e-6;
Fr     = 135.3e3;
LoLinf = 129.32e-6;
Fm     = 580.92e3;
Nb     = 1.3013;
Cp     = 50e-9;

cable.param.r0c = Ro;    
cable.param.r0s = 0;
cable.param.ac  = (Ro^2/Fr)^2;
cable.param.as  = 0;
cable.param.l0  = LoLinf + Linf;
cable.param.loo = Linf; 
cable.param.b   = Nb;     
cable.param.fm  = Fm;    
cable.param.coo = Cp;
cable.param.c0  = 0;
cable.param.ce  = 0;
cable.param.g0  = 0;
cable.param.ge  = 1;
clist=insertList(clist,cable);


cable=[];
cable.name='ETSI-ADSL-PE063m';
cable.model='BT';

Ro     = 113;
Linf   = 477.42e-6;
Fr     = 79.733e3;
LoLinf = 221.84e-6;
Fm     = 265.70e3;
Nb     = 1.0978;
Cp     = 45e-9;

cable.param.r0c = Ro;    
cable.param.r0s = 0;
cable.param.ac  = (Ro^2/Fr)^2;
cable.param.as  = 0;
cable.param.l0  = LoLinf + Linf;
cable.param.loo = Linf; 
cable.param.b   = Nb;     
cable.param.fm  = Fm;    
cable.param.coo = Cp;
cable.param.c0  = 0;
cable.param.ce  = 0;
cable.param.g0  = 0;
cable.param.ge  = 1;
clist=insertList(clist,cable);

cable=[];
cable.name='ETSI-ADSL-PE09m';
cable.model='BT';

Ro     = 55;
Linf   = 520.45e-6;
Fr     = 31.207e3;
LoLinf = 230.34e-6;
Fm     = 124.04e3;
Nb     = 0.9605;
Cp     = 40e-9;

cable.param.r0c = Ro;    
cable.param.r0s = 0;
cable.param.ac  = (Ro^2/Fr)^2;
cable.param.as  = 0;
cable.param.l0  = LoLinf + Linf;
cable.param.loo = Linf; 
cable.param.b   = Nb;     
cable.param.fm  = Fm;    
cable.param.coo = Cp;
cable.param.c0  = 0;
cable.param.ce  = 0;
cable.param.g0  = 0;
cable.param.ge  = 1;
clist=insertList(clist,cable);

%% ===========================================================================
% ETSI ADSL as models from ITU 996.1

cable=[];
cable.name='ETSI-ADSL-PE032i';
cable.model='BT';

cable.param.r0c = .409e3;    
cable.param.r0s = 0;
cable.param.ac  = .3822;
cable.param.as  = 0;
cable.param.l0  = 0.6075e-3;
cable.param.loo = 0.5e-3; 
cable.param.b   = 5.269;     
cable.param.fm  = .609e6;    
cable.param.coo = 40e-9;
cable.param.c0  = 0;
cable.param.ce  = 0;
cable.param.g0  = 0;
cable.param.ge  = 1;
clist=insertList(clist,cable);

cable=[];
cable.name='ETSI-ADSL-PE04i';
cable.model='BT';

cable.param.r0c = .28e3;    
cable.param.r0s = 0;
cable.param.ac  = .0969;
cable.param.as  = 0;
cable.param.l0  = 0.5873e-3;
cable.param.loo = 0.4260e-3; 
cable.param.b   = 1.385;     
cable.param.fm  = .7459e6;    
cable.param.coo = 50e-9;
cable.param.c0  = 0;
cable.param.ce  = 0;
cable.param.g0  = 0;
cable.param.ge  = 1;
clist=insertList(clist,cable);

cable=[];
cable.name='ETSI-ADSL-PE05i';
cable.model='BT';

cable.param.r0c = .1792e3;    
cable.param.r0s = 0;
cable.param.ac  = .0561;
cable.param.as  = 0;
cable.param.l0  = 0.6746e-3;
cable.param.loo = 0.5327e-3; 
cable.param.b   = 1.195;     
cable.param.fm  = .6647e6;    
cable.param.coo = 50e-9;
cable.param.c0  = 0;
cable.param.ce  = 0;
cable.param.g0  = 0;
cable.param.ge  = 1;
clist=insertList(clist,cable);

cable=[];
cable.name='ETSI-ADSL-PE063i';
cable.model='BT';

cable.param.r0c = .113e3;    
cable.param.r0s = 0;
cable.param.ac  = .0257;
cable.param.as  = 0;
cable.param.l0  = 0.6994e-3;
cable.param.loo = 0.4772e-3; 
cable.param.b   = 1.0956;     
cable.param.fm  = .2658e6;    
cable.param.coo = 45e-9;
cable.param.c0  = 0;
cable.param.ce  = 0;
cable.param.g0  = 0;
cable.param.ge  = 1;
clist=insertList(clist,cable);

cable=[];
cable.name='ETSI-ADSL-PE09i';
cable.model='BT';

cable.param.r0c = .0551e3;    
cable.param.r0s = 0;
cable.param.ac  = .0094;
cable.param.as  = 0;
cable.param.l0  = 0.7509e-3;
cable.param.loo = 0.5205e-3; 
cable.param.b   = 0.9604;     
cable.param.fm  = .1238e6;    
cable.param.coo = 40e-9;
cable.param.c0  = 0;
cable.param.ce  = 0;
cable.param.g0  = 0;
cable.param.ge  = 1;
clist=insertList(clist,cable);

%% ===========================================================================
% ETSI ADSL as MAR2 models, curve fitting with above models 
% Ref: ETSI TM6 021t32, Torino, Italy, 4th-8th Feb., 2002.

cable=[];
cable.name='ETSI-ADSL-PE032mar';
cable.model='MAR2';

vars = [400.666842 411.961536e-6 2.156655 39.639546e-9 0.002840]; % optimized
vars = [409 0.00040 2.05 4e-08 0 ]; % handmade

cable.param.R0     = vars(1);      % Roo/km
cable.param.Linf   = vars(2);      % Linf/km
cable.param.a      = vars(3);      % (proximity factor)
cable.param.C1M    = vars(4);      % Cp/km(@1MHz)
cable.param.delta  = vars(5);      % Delta(constant)
clist=insertList(clist,cable);


cable=[];
cable.name='ETSI-ADSL-PE04mar';
cable.model='MAR2';

vars = [277.623806 421.576013e-6 1.470148 49.792437e-9 0.001123 ]; % optimized
vars = [280 0.0004 1.44 5e-08 0 ]; % handmade

cable.param.R0     = vars(1);      % Roo/km
cable.param.Linf   = vars(2);      % Linf/km
cable.param.a      = vars(3);      % (proximity factor)
cable.param.C1M    = vars(4);      % Cp/km(@1MHz)
cable.param.delta  = vars(5);      % Delta(constant)
clist=insertList(clist,cable);


cable=[];
cable.name='ETSI-ADSL-PE05mar';
cable.model='MAR2';

vars = [179.460137 516.017173e-6 1.705113 49.840489e-9 0.002647 ]; % optimized
vars = [179     0.0005 1.79 5e-08 0 ]; % handmade

cable.param.R0     = vars(1);      % Roo/km
cable.param.Linf   = vars(2);      % Linf/km
cable.param.a      = vars(3);      % (proximity factor)
cable.param.C1M    = vars(4);      % Cp/km(@1MHz)
cable.param.delta  = vars(5);      % Delta(constant)
clist=insertList(clist,cable);


cable=[];
cable.name='ETSI-ADSL-PE063mar';
cable.model='MAR2';

vars = [111.100648 471.310664e-6 1.948990 44.685737e-9 0.003210]; % optimized
vars = [113     0.00045 2.01 4.5e-08 0 ]; % handmade


cable.param.R0     = vars(1);      % Roo/km
cable.param.Linf   = vars(2);      % Linf/km
cable.param.a      = vars(3);      % (proximity factor)
cable.param.C1M    = vars(4);      % Cp/km(@1MHz)
cable.param.delta  = vars(5);      % Delta(constant)
clist=insertList(clist,cable);


cable=[];
cable.name='ETSI-ADSL-PE09mar';
cable.model='MAR2';


vars = [54.753441 502.965928e-6 2.446506 39.855129e-9 0.002673]; % optimized
vars = [55 0.0005 2.56 4e-08 0 ]; % handmade

cable.param.R0     = vars(1);      % Roo/km
cable.param.Linf   = vars(2);      % Linf/km
cable.param.a      = vars(3);      % (proximity factor)
cable.param.C1M    = vars(4);      % Cp/km(@1MHz)
cable.param.delta  = vars(5);      % Delta(constant)

clist=insertList(clist,cable);

%% ===========================================================================
% ETSI ADSL as MAR2 models, curve fitting with above models 
% Ref: ETSI TM6 021t32, Torino, Italy, 4th-8th Feb., 2002.

cable=[];
cable.name='ETSI-ADSL-PE032maropt';
cable.model='MAR2';

vars = [400.666842 411.961536e-6 2.156655 39.639546e-9 0.002840]; % optimized

cable.param.R0     = vars(1);      % Roo/km
cable.param.Linf   = vars(2);      % Linf/km
cable.param.a      = vars(3);      % (proximity factor)
cable.param.C1M    = vars(4);      % Cp/km(@1MHz)
cable.param.delta  = vars(5);      % Delta(constant)
clist=insertList(clist,cable);


cable=[];
cable.name='ETSI-ADSL-PE04maropt';
cable.model='MAR2';

vars = [277.623806 421.576013e-6 1.470148 49.792437e-9 0.001123 ]; % optimized

cable.param.R0     = vars(1);      % Roo/km
cable.param.Linf   = vars(2);      % Linf/km
cable.param.a      = vars(3);      % (proximity factor)
cable.param.C1M    = vars(4);      % Cp/km(@1MHz)
cable.param.delta  = vars(5);      % Delta(constant)
clist=insertList(clist,cable);


cable=[];
cable.name='ETSI-ADSL-PE05maropt';
cable.model='MAR2';

vars = [179.460137 516.017173e-6 1.705113 49.840489e-9 0.002647 ]; % optimized

cable.param.R0     = vars(1);      % Roo/km
cable.param.Linf   = vars(2);      % Linf/km
cable.param.a      = vars(3);      % (proximity factor)
cable.param.C1M    = vars(4);      % Cp/km(@1MHz)
cable.param.delta  = vars(5);      % Delta(constant)
clist=insertList(clist,cable);


cable=[];
cable.name='ETSI-ADSL-PE063maropt';
cable.model='MAR2';

vars = [111.100648 471.310664e-6 1.948990 44.685737e-9 0.003210]; % optimized


cable.param.R0     = vars(1);      % Roo/km
cable.param.Linf   = vars(2);      % Linf/km
cable.param.a      = vars(3);      % (proximity factor)
cable.param.C1M    = vars(4);      % Cp/km(@1MHz)
cable.param.delta  = vars(5);      % Delta(constant)
clist=insertList(clist,cable);


cable=[];
cable.name='ETSI-ADSL-PE09maropt';
cable.model='MAR2';


vars = [54.753441 502.965928e-6 2.446506 39.855129e-9 0.002673]; % optimized

cable.param.R0     = vars(1);      % Roo/km
cable.param.Linf   = vars(2);      % Linf/km
cable.param.a      = vars(3);      % (proximity factor)
cable.param.C1M    = vars(4);      % Cp/km(@1MHz)
cable.param.delta  = vars(5);      % Delta(constant)

clist=insertList(clist,cable);
